﻿using System;
using System.Data;
using System.Linq;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using ColumnStyle = Infragistics.Win.UltraWinGrid.ColumnStyle;

namespace UltraGridSelectionChanged
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            ultraGrid1.InitializeLayout += UltraGrid1OnInitializeLayout;
            ultraGrid1.InitializeTemplateAddRow += OnInitializeTemplateAddRow;
            ultraGrid1.AfterSelectChange += UltraGrid1OnAfterSelectChange;
            ultraGrid1.AfterCellActivate += UltraGrid1OnAfterCellActivate;

            InitializeData();
            SetValueLists();
        }

        private void InitializeData()
        {
            var table = new DataTable();

            table.Columns.Add("First", typeof (string));
            table.Columns.Add("Second", typeof (string));
            table.Columns.Add("Third", typeof (string));

            for (var i = 0; i < 3; i++)
            {
                var row = table.NewRow();
                row["First"] = "First" + i;
                row["Second"] = "Second" + i;
                row["Third"] = "Third" + i;
                table.Rows.Add(row);
            }

            ultraGrid1.DataSource = table;
        }

        private void SetValueLists()
        {
            for (var i = 0; i < 3; i++)
            {
                var row = ultraGrid1.Rows[i];

                var valueList = new ValueList();
                valueList.ValueListItems.Add("First" + i);
                valueList.ValueListItems.Add("Second" + i);
                valueList.ValueListItems.Add("Third" + i);

                foreach (var cell in row.Cells)
                {
                    // No Value List for a first column
                    if (cell.Column.Key == "First")
                        continue;

                    cell.ValueList = valueList;
                }
            }
        }

        private void UltraGrid1OnInitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Override.AllowAddNew = AllowAddNew.TemplateOnBottom;
            e.Layout.Override.SelectTypeCell = SelectType.Single;
            e.Layout.Override.SelectTypeCol = SelectType.ExtendedAutoDrag;
            e.Layout.Override.SelectTypeRow = SelectType.Single;
            e.Layout.Override.HeaderClickAction = HeaderClickAction.Select;

            foreach (var column in e.Layout.Bands[0].Columns)
            {
                if (column.Key == "First")
                {
                    // Clicking in a first column should select a row
                    column.CellClickAction = CellClickAction.RowSelect;
                }
                else
                {
                    // All other columns should contain a dropdown (valuelist)
                    column.Style = ColumnStyle.DropDownList;
                    column.CellClickAction = CellClickAction.Edit;
                }
            }
        }

        private void OnInitializeTemplateAddRow(object sender, InitializeTemplateAddRowEventArgs e)
        {
            // NoEdit for a template add row
            e.TemplateAddRow.Activation = Activation.NoEdit;
        }

        private void UltraGrid1OnAfterSelectChange(object sender, AfterSelectChangeEventArgs e)
        {
            var sel = ultraGrid1.Selected.Rows.Cast<UltraGridRow>().Select(r => r.Index).ToList();
            selectChangeLabel.Text = string.Format("Selected Rows (set by AfterSelectChange event): {0}", sel.Count <= 0 ? "none" : string.Join(", ", sel));

            // Set some important data
            const string dataPrefix = "Important data for currently selected row goes here.";
            var dataContent = sel.Count <= 0 ? "Currently not showing any data - no row selected." : string.Format("Currently showing data for a row {0}.", string.Join(", ", sel));
            var dataNewRowNote = sel.Count <= 0 || !ultraGrid1.Selected.Rows.Cast<UltraGridRow>().First().IsAddRow ? string.Empty : "It's a new row template.";
            dataForSelectedRowLabel.Text = string.Format("{0} {1} {2}", dataPrefix, dataContent, dataNewRowNote);
        }

        private void UltraGrid1OnAfterCellActivate(object sender, EventArgs e)
        {
            var sel = ultraGrid1.Selected.Rows.Cast<UltraGridRow>().Select(r => r.Index).ToList();
            cellActivateLabel.Text = string.Format("Selected Rows (set by AfterCellActivate event): {0}", sel.Count <= 0 ? "none" : string.Join(", ", sel));
        }

    }
}
